# Version
require_relative "iupick/version"

# Dependencies
require 'unirest'
require 'json'

# API resources
require_relative "iupick/shipment"
require_relative "iupick/waypoint"

module Iupick

  class << self

    attr_accessor :secret_token, :public_token, :environment

    # Initializes the address dictionary with
    # the values to be passed.
    # This returns a dictionary for versatility.
    def create_address(
      city,
      line_one,
      postal_code,
      line_two='',
      neighborhood=''
    )

      return {
        'city': city,
        'line_one': line_one,
        'line_two': line_two,
        'neighborhood': neighborhood,
        'postal_code': postal_code
      }
    end

    # Initializes the an empty address
    def empty_address()
      return create_address(
        city = 'Empty',
        line_one = 'Empty',
        postal_code = 'Empty',
        line_two = 'Empty',
        neighborhood = 'Empty'
      )
    end

    # Initializes the person_object with
    # the values to be passed.
    # This returns a dictionary for versatility.
    def create_person(
      person_name,
      phone_number,
      email_address,
      title = '',
      company_name = '',
      phone_extension = ''
    )

      return {
        'person_name': person_name,
        'phone_number': phone_number,
        'email_address': email_address,
        'title': title,
        'company_name': company_name,
        'phone_extension': phone_extension
      }
    end

    # Gets the base url, to be used for the API service.
    def get_base_url()
      if environment == 'development'
        return 'http://localhost:8000/api/'
      elsif environment == 'sandbox'
        return 'https://sandbox.iupick.com/api/'
      elsif environment == 'production'
        return 'https://iupick.com/api/'
      end
    end

    # Returns the proper header either public or secret.
    def generate_headers(auth)
      if auth == 'public'
        keyword = 'Token '
        token = public_token
      elsif auth == 'secret'
        keyword = 'Secret '
        token = secret_token
      end
      return {'Authorization': keyword + token}
    end

  end
end
